@@ -1,13 +1,26 @@
-# ----------------------------------------------------------------------------------------------------------------
-# Recursive function that can make a json from complex nested objects
-# ----------------------------------------------------------------------------------------------------------------
+"""Dataclass to json conversion"""
+
+__author__ = "Wytze Bruinsma"
+
+
 def rec_to_json(objects):
-    # ----------------------------------------------------------------------------------------------------------------
-    # Function check if object can be a dict
-    # ----------------------------------------------------------------------------------------------------------------
+    """
+    Recursive function that can make a json from complex nested objects
+
+    :param objects:
+    :return:
+    """
+
     def contains_dict(object):
+        """
+        Function check if object can be a dict
+
+        :param object:
+        :return:
+        """
+
         try:
-            _ = object.__dict__
+            _ = dict(object)
             return True
         except:
             return False
@@ -16,7 +29,7 @@ def rec_to_json(objects):
         return objects
 
     if contains_dict(objects):
-        dic = objects.__dict__
+        dic = dict(objects)
     else:
         dic = objects
 
