@@ -1,24 +1,27 @@
+"""Extra functions for Google Cloud Storage"""
+
 __author__ = "Wytze Bruinsma"
 
-import newlinejson as nlj
 import random
 import string
-from google.cloud import storage
+
+import newlinejson as nlj
+from google.cloud.storage import Client
 
 from vaknl_gcp.Bigquery import BigqueryClient
 from vaknl_gcp.DataClasses import rec_to_json
 
 
-class StorageClient(object):
+class StorageClient(Client):
 
-    def __init__(self, project_id):
-        self.project_id = project_id
+    def __init__(self, project, **kwargs):
+        self.project = project
 
-        self.storage_client = storage.Client(project=project_id)
-        self.bigquery_client = BigqueryClient(project_id=project_id)
+        super().__init__(project=project, **kwargs)
+        self.bigquery_client = BigqueryClient(project=project)
 
-        self.bucket_name = f'storage_to_bigquery-{self.project_id}'
-        self.bucket = self.storage_client.get_bucket(self.bucket_name)
+        self.bucket_name = f'storage_to_bigquery-{self.project}'
+        self.bucket = super().get_bucket(self.bucket_name)
 
     def __rec_compose(self, blobs, blob_name, table_ref, write_disposition, n=0):
         """
@@ -63,7 +66,7 @@ class StorageClient(object):
 
         assert len(objects) > 0, 'List is empty. No data is send'
 
-        if objects_name:
+        if objects_name is None:
             objects_name = objects[0].__class__.__name__  # retrieve name of the first object
         random_string = ''.join(random.choice(string.ascii_lowercase) for _ in
                                 range(12))  # Make blob_base_name unique so processes don't interact
@@ -95,7 +98,7 @@ class StorageClient(object):
             batch_size: how many blobs until composing and sending to google bigquery
             object_name: name of the them object stored in storage 
         """
-        if object_name:
+        if object_name is None:
             object_name = object.__class__.__name__  # retrieve name of the object
         blob_base_name = f'{object_name}_{generate_random_string()}'  # Generate a dynamic name from the object
 
@@ -106,39 +109,10 @@ class StorageClient(object):
         blobs = self.list_blobs_with_prefix(bucket_name=self.bucket_name, prefix=f'import/{object_name}/')
 
         if len(blobs) > batch_size:
-            self.__rec_compose(blobs=blobs, blob_name=f'{object_name}_{generate_random_string()}', table_ref=table_ref,
+            self.__rec_compose(blobs=blobs, blob_name=f'{object_name}_{generate_random_string()}',
+                               table_ref=table_ref,
                                write_disposition=write_disposition)
 
-    def get_blobs_from_bucket(self, bucket_name):
-        """
-        Args:
-            bucket_name: bucket_name
-        
-        Return:
-            list: blobs
-        """
-        return self.storage_client.list_blobs(bucket_name)
-
-    def upload_from_string(self, blob, string):
-        """
-        Args:
-            blob: blob
-            string: data to write in the blob
-        Return:
-            string: url
-        """
-        blob.upload_from_string(string)
-        return blob.public_url
-
-    def get_bucket(self, bucket_name):
-        """
-        Args:
-            string: bucket_name
-        Return:
-            string: url
-        """
-        return self.storage_client.get_bucket(bucket_name)
-
     def list_blobs_with_prefix(self, bucket_name, prefix, delimiter=None):
         """
         Lists all the blobs in the bucket that begin with the prefix.
@@ -174,7 +148,7 @@ class StorageClient(object):
             list: blobs
         """
 
-        blobs = self.storage_client.list_blobs(
+        blobs = super().list_blobs(
             bucket_name, prefix=prefix, delimiter=delimiter
         )
 
